
![landing](https://user-images.githubusercontent.com/1019791/222645884-fd88cd66-3dd0-4b6e-98f4-65586040e538.png)

# peegeem

> Probabilistic graphical models that are fun to work with <br>

This simple library is meant as a demo that shows what might be possible when you combine domain specific languages with bespoke UI tools. You might end up with a domain specific environment as a result!

## Install

You can install via pip.

```
uv pip install peegeem
```

## Demo 

A Github readme won't do the idea of this library any justice, we commend checking out the interactive notebook on Github pages instead. 
